# p11kit / update-ca-trust leaves the directory unwritable
/usr/bin/unlink /usr/share/pki/ca-trust-source/anchors/isrg-intermediate-r3.pem
/usr/bin/unlink /usr/share/pki/ca-trust-source/blacklist/trustid-root-x3.pem
/usr/bin/update-ca-trust
