# p11kit / update-ca-trust leaves the directory unwritable
chmod u+w /etc/pki/ca-trust/extracted/pem/directory-hash
/usr/bin/ln -s /usr/share/pki/letsencrypt/isrg-intermediate-r3.pem /usr/share/pki/ca-trust-source/anchors/
/usr/bin/ln -s /usr/share/pki/letsencrypt/trustid-root-x3.pem /usr/share/pki/ca-trust-source/blacklist
/usr/bin/update-ca-trust
